=== modified file 'lib/canonical/codehosting/tests/helpers.py'
--- lib/canonical/codehosting/tests/helpers.py	2007-09-11 07:48:49 +0000
+++ lib/canonical/codehosting/tests/helpers.py	2007-10-09 09:56:57 +0000
@@ -6,7 +6,8 @@
 __all__ = [
     'AvatarTestCase', 'CodeHostingTestProviderAdapter',
     'CodeHostingRepositoryTestProviderAdapter', 'FakeLaunchpad',
-    'ServerTestCase', 'adapt_suite', 'deferToThread']
+    'ServerTestCase', 'adapt_suite', 'deferToThread',
+    'make_bazaar_branch_and_tree']
 
 import os
 import shutil
@@ -16,12 +17,16 @@
 
 import transaction
 
+from bzrlib.bzrdir import BzrDir
+from bzrlib.errors import FileExists
 from bzrlib.tests import TestCaseWithTransport
 
 from zope.component import getUtility
 from zope.security.management import getSecurityPolicy, setSecurityPolicy
 from zope.security.simplepolicies import PermissiveSecurityPolicy
 
+from canonical.codehosting.transport import branch_id_to_path
+from canonical.config import config
 from canonical.database.sqlbase import cursor
 from canonical.launchpad.interfaces import (
     BranchType, IBranchSet, IPersonSet, IProductSet, PersonCreationRationale,
@@ -348,6 +353,25 @@
         return result
 
 
+def make_bazaar_branch_and_tree(db_branch):
+    assert db_branch.branch_type == BranchType.HOSTED, (
+        "Can only create branches for HOSTED branches: %r"
+        % db_branch)
+    branch_dir = os.path.join(
+        config.codehosting.branches_root, branch_id_to_path(db_branch.id))
+
+    if not os.path.exists(branch_dir):
+        os.makedirs(branch_dir)
+    try:
+        tree = BzrDir.create_standalone_workingtree(branch_dir)
+    except FileExists:
+        return
+    f = open(os.path.join(branch_dir, 'hello'), 'w')
+    f.write('foo')
+    f.close()
+    tree.commit('message')
+
+
 def adapt_suite(adapter, base_suite):
     from bzrlib.tests import iter_suite_tests
     suite = unittest.TestSuite()

=== added file 'utilities/make-dummy-hosted-branches'
--- utilities/make-dummy-hosted-branches	1970-01-01 00:00:00 +0000
+++ utilities/make-dummy-hosted-branches	2007-10-09 09:56:57 +0000
@@ -0,0 +1,37 @@
+#!/usr/bin/python2.4
+# Copyright 2007 Canonical Ltd.  All rights reserved.
+
+import _pythonpath
+
+import sys
+
+from bzrlib import config
+
+from zope.component import getUtility
+
+from canonical.codehosting.tests.helpers import make_bazaar_branch_and_tree
+from canonical.database.sqlbase import sqlvalues
+from canonical.launchpad.database import Branch
+from canonical.launchpad.interfaces import BranchType
+from canonical.launchpad.scripts import execute_zcml_for_scripts
+from canonical.lp import initZopeless
+
+
+def main(argv):
+    execute_zcml_for_scripts()
+    ztm = initZopeless()
+    conf = config.GlobalConfig()
+    signing_policy = conf.get_user_option('create_signatures')
+    conf.set_user_option('create_signatures', 'never')
+    try:
+        branches = Branch.select(
+            "Branch.branch_type = %s" % sqlvalues(BranchType.HOSTED))
+        for branch in branches:
+            make_bazaar_branch_and_tree(branch)
+    finally:
+        conf.set_user_option('create_signatures', signing_policy)
+        ztm.abort()
+
+
+if __name__ == '__main__':
+    sys.exit(main(sys.argv))

